SystemOrganization addCategory: #ConfigurationOfZincHTTPComponents!

Object subclass: #ConfigurationOfZincHTTPComponents
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfZincHTTPComponents'!

!ConfigurationOfZincHTTPComponents commentStamp: 'SvenVanCaekenberghe 1/15/2011 18:04' prior: 0!
I am ConfigurationOfZincHTTPComponents the Metacello configuration of Zinc HTTP Components, an open-source Smalltalk framework to deal with the HTTP networking protocol.

For more information, see http://homepage.mac.com/svc/Zinc-HTTP-Components

One way to load this project is by executing:

	ConfigurationOfZincHTTPComponents project latestVersion load.
	ConfigurationOfZincHTTPComponents project latestVersion load: 'Tests'.

This is open-source software licensed under the MIT License.!

!ConfigurationOfZincHTTPComponents class methodsFor: 'private' stamp: 'SvenVanCaekenberghe 1/15/2011 17:31'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfZincHTTPComponents class methodsFor: 'private' stamp: 'SvenVanCaekenberghe 1/15/2011 17:31'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
					"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfZincHTTPComponents class methodsFor: 'metacello tool support' stamp: 'SvenVanCaekenberghe 1/15/2011 17:31'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfZincHTTPComponents class methodsFor: 'metacello tool support' stamp: 'SvenVanCaekenberghe 1/15/2011 17:31'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfZincHTTPComponents class methodsFor: 'loading' stamp: 'SvenVanCaekenberghe 1/15/2011 17:31'!
load
	"self load"

	^self project stableVersion load! !

!ConfigurationOfZincHTTPComponents class methodsFor: 'metacello tool support' stamp: 'SvenVanCaekenberghe 1/15/2011 17:31'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfZincHTTPComponents class methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 1/15/2011 17:31'!
project

	^self new project! !

!ConfigurationOfZincHTTPComponents class methodsFor: 'unloading Metacello' stamp: 'SvenVanCaekenberghe 1/15/2011 17:31'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfZincHTTPComponents methodsFor: 'baselines' stamp: 'PaulDeBruicker 6/2/2011 09:09'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec 
			blessing: #baseline;
			description: 'Baseline for Zinc HTTP Components, a framework to deal with the HTTP networking';
			author: 'SvenVanCaekenberghe';
			repository: 'http://www.squeaksource.com/ZincHTTPComponents'.	
		spec project: 'Seaside30' with: [
				spec
					className: 'ConfigurationOfSeaside30';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec package: 'Zodiac' with: [spec repository: 'http://www.squeaksource.com/Zodiac'].
		spec 
			package: 'Zinc-HTTP';
			package: 'Zinc-Patch-HTTPSocket' with: [ spec requires: 'Zinc-HTTP' ];
			package: 'Zinc-AWS' with: [ spec requires: 'Zinc-HTTP' ];
			package: 'Zinc-Zodiac' with: [ spec requires:#('Zodiac' 'Zinc-HTTP') ];
			package: 'Zinc-Tests' with: [ spec requires: 'Zinc-HTTP' ];
			package: 'Zinc-Seaside' with: [ spec requires: #('Zinc-HTTP' 'Seaside30') ].
		spec
			group: 'default' with: #('Core');
			group: 'Core' with: #('Zinc-HTTP');
			group: 'Tests' with: #('Zinc-Tests');
			group: 'Zodiac' with: #('Zinc-Zodiac');
			group: 'Seaside' with: #('Zinc-Seaside');
			group: 'Patch-HTTPSocket' with: #('Zinc-Patch-HTTPSocket') ].
		
	spec for: #gemstone do:[
		spec repository: 'http://seaside.gemstone.com/ss/ZincHTTPComponents'.  
		spec
			package:'SocketStream' with:[spec repository: 'http://seaside.gemstone.com/ss/PharoCompat' ];
			package:'Seaside-GemStone-Adaptors-Zinc' with:[spec requires: #('Zinc-Gemstone' 'Zinc-Seaside')] ;
			package:'Zinc-GemstonePreliminary' with:[spec requires: #('SocketStream')  ];
			package:'Zinc-HTTP' with:[spec requires: #('Zinc-GemstonePreliminary')  ];
			package:'Zinc-Gemstone' with:[spec requires: #('Zinc-HTTP')  ];
			package: 'Zinc-Tests' with: [ spec requires: 'Zinc-Gemstone' ].
		spec
			group: 'default' with: #('Core');
			group: 'Core' with: #('Zinc-Gemstone');
			group: 'Tests' with: #('Zinc-Tests');
			group: 'Seaside' with: #('Seaside-GemStone-Adaptors-Zinc').
		
		]! !

!ConfigurationOfZincHTTPComponents methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 1/15/2011 17:31'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfZincHTTPComponents methodsFor: 'accessing' stamp: 'PaulDeBruicker 6/1/2011 13:32'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '1.1'.
	spec for: #'gemstone' version: '1.1'.! !

!ConfigurationOfZincHTTPComponents methodsFor: 'versions' stamp: 'PaulDeBruicker 6/1/2011 23:13'!
version10: spec 
	<version: '1.0' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec 
			package: 'Zinc-HTTP' with: 'Zinc-HTTP-PaulDeBruicker.140';
			package: 'Zinc-Tests' with: 'Zinc-Tests-SvenVanCaekenberghe.75';
			package: 'Zinc-AWS' with:'Zinc-AWS-SvenVanCaekenberghe.7';
			package: 'Zinc-Patch-HTTPSocket' with:'Zinc-Patch-HTTPSocket-SvenVanCaekenberghe.1';
			package: 'Zinc-Seaside' with:'Zinc-Seaside-PaulDeBruicker.13';
			project:'Seaside30' with: '3.0.4' ].
		
	spec for: #gemstone do:[
		spec blessing: #release.
		spec 
			package: 'Zinc-GemstonePreliminary' with: 'Zinc-GemstonePreliminary-PaulDeBruicker.2';
			package: 'Zinc-Gemstone' with: 'Zinc-Gemstone-PaulDeBruicker.8';
			package:'SocketStream' with:'SocketStream-PaulDeBruicker.12';
			package:'Seaside-GemStone-Adaptors-Zinc' with: 'Seaside-GemStone-Adaptors-Zinc-PaulDeBruicker.3'   		
		]! !

!ConfigurationOfZincHTTPComponents methodsFor: 'versions' stamp: 'PaulDeBruicker 6/2/2011 08:46'!
version11: spec 
	<version: '1.1' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec 
			package: 'Zinc-HTTP' with: 'Zinc-HTTP-SvenVanCaekenberghe.162';
			package: 'Zinc-Tests' with: 'Zinc-Tests-SvenVanCaekenberghe.84';
			package: 'Zinc-AWS' with:'Zinc-AWS-SvenVanCaekenberghe.7';
			package: 'Zinc-Zodiac' with:'Zinc-Zodiac-SvenVanCaekenberghe.4';
			package: 'Zinc-Patch-HTTPSocket' with:'Zinc-Patch-HTTPSocket-SvenVanCaekenberghe.1';
			package: 'Zinc-Seaside' with:'Zinc-Seaside-SvenVanCaekenberghe.16';
			project:'Seaside30' with: '3.0.5';
			package:'Zodiac' with: 'Zodiac-Core-SvenVanCaekenberghe.8' ].
		
	spec for: #gemstone do:[
		spec blessing: #release.
		spec 
			package: 'Zinc-GemstonePreliminary' with: 'Zinc-GemstonePreliminary-PaulDeBruicker.2';
			package: 'Zinc-Gemstone' with: 'Zinc-Gemstone-PaulDeBruicker.14';
			package:'SocketStream' with:'SocketStream-PaulDeBruicker.12';
			package:'Seaside-GemStone-Adaptors-Zinc' with: 'Seaside-GemStone-Adaptors-Zinc-PaulDeBruicker.3'   		
		]! !
